@@ -5283,25 +5283,74 @@ test!(
     |_| chain!(class_properties(), async_to_generator()),
     issue_1694_2,
     "
+class MyClass {
+    static #get() {
+        return 1
+    }
+    constructor() {
+        MyClass.#get(foo);
+    }
+}
+",
+    "
+  var _get = new WeakSet();
   class MyClass {
-      static #get() {
-          return 1
-      }
-      constructor() {
-          MyClass.#get(foo);
+      constructor(){
+          _get.add(this);
+          _classStaticPrivateMethodGet(MyClass, MyClass, get).call(MyClass, foo);
       }
   }
-  ",
+  function get() {
+      return 1;
+  }
+  "
+);
+
+test!(
+    syntax(),
+    |_| chain!(class_properties(), async_to_generator()),
+    issue_1702_1,
     "
-    var _get = new WeakSet();
-    class MyClass {
+    class Foo {
+      #y;
+      static #z = 3;
+    
+      constructor() {
+        this.x = 1;
+        this.#y = 2;
+        this.#sssss();
+      }
+    
+      #sssss() {
+        console.log(this.x, this.#y, Foo.#z);
+      }
+    }
+    
+    const instance = new Foo();
+    ",
+    "
+    var _sssss = new WeakSet();
+    class Foo {
         constructor(){
-            _get.add(this);
-            _classStaticPrivateMethodGet(MyClass, MyClass, get).call(MyClass, foo);
+            _y.set(this, {
+                writable: true,
+                value: void 0
+            });
+            _sssss.add(this);
+            this.x = 1;
+            _classPrivateFieldSet(this, _y, 2);
+            _classPrivateMethodGet(this, _sssss, sssss).call(this);
         }
     }
-    function get() {
-        return 1;
+    var _y = new WeakMap();
+    var _z = {
+        writable: true,
+        value: 3
+    };
+    function sssss() {
+        console.log(this.x, _classPrivateFieldGet(this, _y), _classStaticPrivateFieldSpecGet(Foo, \
+     Foo, _z));
     }
+    const instance = new Foo();
     "
 );
